==> kde-runtime-4.9.95.tar.xz: kde-runtime-4.9.95/nepomuk/kioslaves/search/queryutils.h <==
/*
   This file is part of the Nepomuk KDE project.
   Copyright (C) 2010 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) version 3, or any
   later version accepted by the membership of KDE e.V. (or its
   successor approved by the membership of KDE e.V.), which shall
   act as a proxy defined in Section 6 of version 3 of the license.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef QUERYUTILS_H
#define QUERYUTILS_H

#include "kext.h"

#include <KUrl>
#include <KDebug>

#include <Nepomuk2/Query/Query>
#include <Nepomuk2/Query/OptionalTerm>
#include <Nepomuk2/Query/ComparisonTerm>
#include <Nepomuk2/Query/AndTerm>
#include <Nepomuk2/Vocabulary/NIE>
#include <Nepomuk2/Vocabulary/NFO>

using namespace Nepomuk2::Vocabulary;

namespace Nepomuk2 {
    namespace Query {
        /**
         * KIO specific query handling shared by the KIO slave and the kded search module
         */
        bool parseQueryUrl( const KUrl& url, Query& query, QString& sparqlQuery )
        {
            // parse URL (this may fail in which case we fall back to pure SPARQL below)
            query = Nepomuk2::Query::Query::fromQueryUrl( url );

            if( query.isValid() ) {
                kDebug() << "Extracted query" << query;

                // request properties to easily create UDSEntry instances
                QList<Query::RequestProperty> reqProperties;

                // In Nepomuk kioslaves, one only shows results with a nie:urls (not just file queries)
                reqProperties << Query::RequestProperty( NIE::url(), false /*non optional*/ );
                query.setRequestProperties( reqProperties );
#ifdef Q_OS_UNIX
                // file size
                ComparisonTerm contentSizeTerm( NFO::fileSize(), Term() );
                contentSizeTerm.setVariableName( QLatin1String("size") );
                // mimetype
                ComparisonTerm mimetypeTerm( NIE::mimeType(), Term() );
                mimetypeTerm.setVariableName( QLatin1String("mime") );
                // mtime
                ComparisonTerm mtimeTerm( NIE::lastModified(), Term() );
                mtimeTerm.setVariableName( QLatin1String("mtime") );
                // mode
                ComparisonTerm modeTerm( KExt::unixFileMode(), Term() );
                modeTerm.setVariableName( QLatin1String("mode") );
                // user
                ComparisonTerm userTerm( KExt::unixFileOwner(), Term() );
                userTerm.setVariableName( QLatin1String("user") );
                // group
                ComparisonTerm groupTerm( KExt::unixFileGroup(), Term() );
                groupTerm.setVariableName( QLatin1String("group") );

                // instead of separate request properties we use one optional and term. That way
                // all or none of the properties will be bound which makes handling the data in
                // SearchFolder::statResult much simpler.
                AndTerm filePropertiesTerm;
                filePropertiesTerm.addSubTerm( contentSizeTerm );
                filePropertiesTerm.addSubTerm( mimetypeTerm );
                filePropertiesTerm.addSubTerm( mtimeTerm );
                filePropertiesTerm.addSubTerm( modeTerm );
                filePropertiesTerm.addSubTerm( userTerm );
                filePropertiesTerm.addSubTerm( groupTerm );
                query = query && OptionalTerm::optionalizeTerm( filePropertiesTerm );
#endif // Q_OS_UNIX
            }
            else {
                // the URL contains pure sparql.
                sparqlQuery = Nepomuk2::Query::Query::sparqlFromQueryUrl( url );
                kDebug() << "Extracted SPARL query" << sparqlQuery;
            }

            return query.isValid() || !sparqlQuery.isEmpty();
        }
    }
}

#endif // QUERYUTILS_H

==> kde-runtime-4.12.5.tar.xz: kde-runtime-4.12.5/nepomuk/kioslaves/search/queryutils.h <==
/*
   This file is part of the Nepomuk KDE project.
   Copyright (C) 2010 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) version 3, or any
   later version accepted by the membership of KDE e.V. (or its
   successor approved by the membership of KDE e.V.), which shall
   act as a proxy defined in Section 6 of version 3 of the license.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef QUERYUTILS_H
#define QUERYUTILS_H

#include "kext.h"

#include <KUrl>
#include <KDebug>

#include <Nepomuk2/Query/Query>
#include <Nepomuk2/Query/OptionalTerm>
#include <Nepomuk2/Query/ComparisonTerm>
#include <Nepomuk2/Query/AndTerm>
#include <Nepomuk2/Vocabulary/NIE>
#include <Nepomuk2/Vocabulary/NFO>

using namespace Nepomuk2::Vocabulary;

namespace Nepomuk2 {
    namespace Query {
        /**
         * KIO specific query handling shared by the KIO slave and the kded search module
         */
        bool parseQueryUrl( const KUrl& url, Query& query, QString& sparqlQuery )
        {
            // parse URL (this may fail in which case we fall back to pure SPARQL below)
            query = Nepomuk2::Query::Query::fromQueryUrl( url );

            if( query.isValid() ) {
                QList<Query::RequestProperty> reqProperties;

                reqProperties << Query::RequestProperty( NIE::url(), false );
                query.setRequestProperties( reqProperties );
            }
            else {
                // the URL contains pure sparql.
                sparqlQuery = Nepomuk2::Query::Query::sparqlFromQueryUrl( url );
                kDebug() << "Extracted SPARL query" << sparqlQuery;
            }

            return query.isValid() || !sparqlQuery.isEmpty();
        }
    }
}

#endif // QUERYUTILS_H
